# -*- coding: utf-8 -*-
""" These are constants used by various openclip submodules.

The ``openclip.constants`` module provides module constants used for various reusable needs.
The constants take their value from the calling program environment
(if available), and default to the expected values.

.. note:: if bash environment variable Eg. ``OPENCLIP_EXT`` is set it will be used
    by python scripts running in that environment (if not set programmatically)
"""
import os
import inspect
import sys
import errno
from . import LOG
from .internal import _MODULE_PATH


try:
    OPENCLIP_VERSION = '3'
    """default OpenClip XML Version"""

    OPENCLIP_EXT = '.clip'
    """default OpenClip file extension"""

    TEST_CLIP_PATH = os.environ.get('OPENCLIP_TEST_CLIP_PATH', os.path.join(_MODULE_PATH,'data','test.clip'))
    """path to test openclip xml file"""

    OPENCLIP_VERSION_FORMAT = os.environ.get('OPENCLIP_VERSION_FORMAT', 'v{:0>3d}')
    """default version format string with zero-padding of 3 Eg. ``v003`` for version `3`"""

    OPENCLIP_PATH = os.environ.get('OPENCLIP_PATH', _MODULE_PATH)
    """the module's path attribute for convenience

    this uses the internal attribute ``_MODULE_PATH`` to generate it's path"""

    OPENCLIP_MIN_FRAME_PAD = os.environ.get('OPENCLIP_MIN_FRAME_PAD', 4)
    """default frame number padding Eg. ``frame.0001.dpx``"""
    OPENCLIP_DEVEL = True if os.environ.get('OPENCLIP_DEVEL', False) in ['1', 'true', 'True'] else False
    """``DEVEL`` state for more verbose logging
    ie. If you want more debugging set the ``OPENCLIP_DEVEL`` environment variable"""

    LOG.debug(u'OPENCLIP_DEVEL attribute is {0}'.format(OPENCLIP_DEVEL) )

except ValueError, e:
    LOG.error(errno.EINVAL, e.message)

