# -*- coding: utf-8 -*-
"""
    openclip/exceptions.py
    =======================================

    provides custom OpenClip base and sub-classed exceptions
"""
__all__ = [
    'InvalidOpenClipFile', 'InvalidOpenClipVersionString',
    'OpenClipFormatError', 'OpenClipEnvError'
]


class BaseOpenClipException(Exception):
    """base exception for custom OpenClip exceptions"""
    def __init__(self, message=None):
        if not message:
            message = "Unknown OpenClip Exception."
        self.message = message
        super(BaseOpenClipException, self).__init__(self.message)


class InvalidOpenClipFile(BaseOpenClipException):
    """exception for invalid clip file errors"""
    def __init__(self, message=None):
        super(InvalidOpenClipFile, self).__init__(message)


class InvalidOpenClipVersionString(BaseOpenClipException):
    """exception for invalid version name errors"""
    def __init__(self, message=None):
        super(InvalidOpenClipVersionString, self).__init__(message)


class OpenClipFormatError(BaseOpenClipException):
    """exception for seq format errors"""
    def __init__(self, message=None):
        super(OpenClipFormatError, self).__init__(message)


class OpenClipEnvError(BaseOpenClipException):
    """exception for openclip environment errors"""
    def __init__(self, message=None):
        super(OpenClipEnvError, self).__init__(message)


